# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls

def install():
    # Declaring local variables
    tresorit_installed = installed_softwares('Tresorit')
    
    # Installing the software if not already installed
    if not tresorit_installed:
        install_exe_if_needed('Tresorit.exe',
            silentflags='/s /v"/qn"',
            min_version=control.get_software_version(),
        )
        
    # Searching for the Tresorit uninstall key dynamically
    uninstall_key = None
    for software in installed_softwares('Tresorit'):
        if 'Tresorit' in software['name']:
            uninstall_key = software['key']
            break
    
    if uninstall_key:
        print(f"Uninstall key for Tresorit: {uninstall_key}")
        # You can store this key for later use, e.g., during the uninstall process
    else:
        print("Could not find uninstall key for Tresorit.")


def uninstall():
    # Searching for the Tresorit uninstall key dynamically
    uninstall_key = None
    uninstall_string = None

    # Searching for the uninstall string dynamically
    for software in installed_softwares('Tresorit'):
        if 'Tresorit' in software['name']:
            uninstall_key = software['key']
            uninstall_string = software['uninstall_string']
            break
    
    if uninstall_string:
        # Adding silent uninstall flag
        if 'msiexec' in uninstall_string.lower():
            uninstall_string += ' /qn'  # For MSI-based uninstallation
        else:
            uninstall_string += ' /S'   # For EXE-based uninstallation, assuming /S for silent
        
        print(f"Uninstalling Tresorit silently using command: {uninstall_string}")
        run(uninstall_string)
    else:
        print("Tresorit is not installed or uninstall string not found.")
